@@ -20,10 +20,10 @@ impl AsyncReaderBuilder {
     ///
     /// ```
     /// use std::error::Error;
-    /// use tokio::stream::StreamExt;
     /// use csv_async::AsyncReaderBuilder;
+    /// use tokio_stream::StreamExt;
     ///
-    /// # fn main() { tokio::runtime::Runtime::new().unwrap().block_on(async {example().await.unwrap()}); }
+    /// # fn main() { tokio1::runtime::Runtime::new().unwrap().block_on(async {example().await.unwrap()}); }
     /// async fn example() -> Result<(), Box<dyn Error>> {
     ///     let data = "\
     /// city,country,pop
@@ -38,16 +38,7 @@ impl AsyncReaderBuilder {
     ///     Ok(())
     /// }
     /// ```
-    pub fn create_reader<R: io::AsyncRead + std::marker::Unpin>(&self, rdr: R) -> AsyncReader<R> {
-        AsyncReader::new(self, rdr)
-    }
-    
-    /// Build a CSV parser from this configuration that reads data from `rdr`.
-    #[deprecated(
-        since = "1.0.1",
-        note = "Please use AsyncReaderBuilder::create_reader function instead"
-    )]
-    pub fn from_reader<R: io::AsyncRead + std::marker::Unpin>(&self, rdr: R) -> AsyncReader<R> {
+    pub fn create_reader<R: io::AsyncRead + Unpin + Send + Sync>(&self, rdr: R) -> AsyncReader<R> {
         AsyncReader::new(self, rdr)
     }
 }
@@ -60,7 +51,7 @@ impl AsyncReaderBuilder {
 ///
 /// # Configuration
 ///
-/// A CSV reader has convenient constructor method `from_reader`.
+/// A CSV reader has convenient constructor method `create_reader`.
 /// However, if you want to configure the CSV reader to use
 /// a different delimiter or quote character (among many other things), then
 /// you should use a [`AsyncReaderBuilder`](struct.AsyncReaderBuilder.html) to construct
@@ -68,10 +59,10 @@ impl AsyncReaderBuilder {
 ///
 /// ```
 /// use std::error::Error;
-/// use tokio::stream::StreamExt;
 /// use csv_async::AsyncReaderBuilder;
+/// use tokio_stream::StreamExt;
 ///
-/// # fn main() { tokio::runtime::Runtime::new().unwrap().block_on(async {example().await.unwrap()}); }
+/// # fn main() { tokio1::runtime::Runtime::new().unwrap().block_on(async {example().await.unwrap()}); }
 /// async fn example() -> Result<(), Box<dyn Error>> {
 ///     let data = "\
 /// city;country;pop
@@ -79,7 +70,7 @@ impl AsyncReaderBuilder {
 /// ";
 ///     let mut rdr = AsyncReaderBuilder::new()
 ///         .delimiter(b';')
-///         .from_reader(data.as_bytes());
+///         .create_reader(data.as_bytes());
 ///
 ///     let mut records = rdr.records();
 ///     assert_eq!(records.next().await.unwrap()?, vec!["Boston", "United States", "4628910"]);
@@ -128,7 +119,7 @@ pub struct AsyncReader<R>(AsyncReaderImpl<R>);
 
 impl<'r, R> AsyncReader<R>
 where
-    R: io::AsyncRead + std::marker::Unpin + 'r,
+    R: io::AsyncRead + Unpin + Send + Sync + 'r,
 {
     /// Create a new CSV reader given a builder and a source of underlying
     /// bytes.
@@ -145,10 +136,10 @@ where
     ///
     /// ```
     /// use std::error::Error;
-    /// use tokio::stream::StreamExt;
     /// use csv_async::AsyncReader;
+    /// use tokio_stream::StreamExt;
     ///
-    /// # fn main() { tokio::runtime::Runtime::new().unwrap().block_on(async {example().await.unwrap()}); }
+    /// # fn main() { tokio1::runtime::Runtime::new().unwrap().block_on(async {example().await.unwrap()}); }
     /// async fn example() -> Result<(), Box<dyn Error>> {
     ///     let data = "\
     /// city,country,pop
@@ -181,10 +172,10 @@ where
     ///
     /// ```
     /// use std::error::Error;
-    /// use tokio::stream::StreamExt;
     /// use csv_async::AsyncReader;
+    /// use tokio_stream::StreamExt;
     ///
-    /// # fn main() { tokio::runtime::Runtime::new().unwrap().block_on(async {example().await.unwrap()}); }
+    /// # fn main() { tokio1::runtime::Runtime::new().unwrap().block_on(async {example().await.unwrap()}); }
     /// async fn example() -> Result<(), Box<dyn Error>> {
     ///     let data = "\
     /// city,country,pop
@@ -219,10 +210,10 @@ where
     ///
     /// ```
     /// use std::error::Error;
-    /// use tokio::stream::StreamExt;
     /// use csv_async::AsyncReader;
+    /// use tokio_stream::StreamExt;
     ///
-    /// # fn main() { tokio::runtime::Runtime::new().unwrap().block_on(async {example().await.unwrap()}); }
+    /// # fn main() { tokio1::runtime::Runtime::new().unwrap().block_on(async {example().await.unwrap()}); }
     /// async fn example() -> Result<(), Box<dyn Error>> {
     ///     let data = "\
     /// city,country,pop
@@ -254,10 +245,10 @@ where
     ///
     /// ```
     /// use std::error::Error;
-    /// use tokio::stream::StreamExt;
     /// use csv_async::AsyncReader;
+    /// use tokio_stream::StreamExt;
     ///
-    /// # fn main() { tokio::runtime::Runtime::new().unwrap().block_on(async {example().await.unwrap()}); }
+    /// # fn main() { tokio1::runtime::Runtime::new().unwrap().block_on(async {example().await.unwrap()}); }
     /// async fn example() -> Result<(), Box<dyn Error>> {
     ///     let data = "\
     /// city,country,pop
@@ -291,10 +282,10 @@ where
     ///
     /// ```
     /// use std::error::Error;
-    /// use tokio::stream::StreamExt;
     /// use csv_async::AsyncReader;
+    /// use tokio_stream::StreamExt;
     ///
-    /// # fn main() { tokio::runtime::Runtime::new().unwrap().block_on(async {example().await.unwrap()}); }
+    /// # fn main() { tokio1::runtime::Runtime::new().unwrap().block_on(async {example().await.unwrap()}); }
     /// async fn example() -> Result<(), Box<dyn Error>> {
     ///     let data = "\
     /// city,country,pop
@@ -333,10 +324,10 @@ where
     ///
     /// ```
     /// use std::error::Error;
-    /// use tokio::stream::StreamExt;
     /// use csv_async::AsyncReader;
+    /// use tokio_stream::StreamExt;
     ///
-    /// # fn main() { tokio::runtime::Runtime::new().unwrap().block_on(async {example().await.unwrap()}); }
+    /// # fn main() { tokio1::runtime::Runtime::new().unwrap().block_on(async {example().await.unwrap()}); }
     /// async fn example() -> Result<(), Box<dyn Error>> {
     ///     let data = "\
     /// city,country,pop
@@ -390,10 +381,10 @@ where
     ///
     /// ```
     /// use std::error::Error;
-    /// use tokio::stream::StreamExt;
     /// use csv_async::AsyncReader;
+    /// use tokio_stream::StreamExt;
     ///
-    /// # fn main() { tokio::runtime::Runtime::new().unwrap().block_on(async {example().await.unwrap()}); }
+    /// # fn main() { tokio1::runtime::Runtime::new().unwrap().block_on(async {example().await.unwrap()}); }
     /// async fn example() -> Result<(), Box<dyn Error>> {
     ///     let data = "\
     /// city,country,pop
@@ -439,7 +430,7 @@ where
     /// use std::error::Error;
     /// use csv_async::{AsyncReader, StringRecord};
     ///
-    /// # fn main() { tokio::runtime::Runtime::new().unwrap().block_on(async {example().await.unwrap()}); }
+    /// # fn main() { tokio1::runtime::Runtime::new().unwrap().block_on(async {example().await.unwrap()}); }
     /// async fn example() -> Result<(), Box<dyn Error>> {
     ///     let data = "\
     /// city,country,pop
@@ -471,7 +462,7 @@ where
     /// use std::error::Error;
     /// use csv_async::{AsyncReader, ByteRecord};
     ///
-    /// # fn main() { tokio::runtime::Runtime::new().unwrap().block_on(async {example().await.unwrap()}); }
+    /// # fn main() { tokio1::runtime::Runtime::new().unwrap().block_on(async {example().await.unwrap()}); }
     /// async fn example() -> Result<(), Box<dyn Error>> {
     ///     let data = "\
     /// city,country,pop
@@ -511,7 +502,7 @@ where
     /// use std::error::Error;
     /// use csv_async::{AsyncReader, StringRecord};
     ///
-    /// # fn main() { tokio::runtime::Runtime::new().unwrap().block_on(async {example().await.unwrap()}); }
+    /// # fn main() { tokio1::runtime::Runtime::new().unwrap().block_on(async {example().await.unwrap()}); }
     /// async fn example() -> Result<(), Box<dyn Error>> {
     ///     let data = "\
     /// city,country,pop
@@ -553,7 +544,7 @@ where
     /// use std::error::Error;
     /// use csv_async::{ByteRecord, AsyncReader};
     ///
-    /// # fn main() { tokio::runtime::Runtime::new().unwrap().block_on(async {example().await.unwrap()}); }
+    /// # fn main() { tokio1::runtime::Runtime::new().unwrap().block_on(async {example().await.unwrap()}); }
     /// async fn example() -> Result<(), Box<dyn Error>> {
     ///     let data = "\
     /// city,country,pop
@@ -586,10 +577,10 @@ where
     /// ```
     /// use std::error::Error;
     /// use std::io;
-    /// use tokio::stream::StreamExt;
     /// use csv_async::{AsyncReader, Position};
+    /// use tokio_stream::StreamExt;
     ///
-    /// # fn main() { tokio::runtime::Runtime::new().unwrap().block_on(async {example().await.unwrap()}); }
+    /// # fn main() { tokio1::runtime::Runtime::new().unwrap().block_on(async {example().await.unwrap()}); }
     /// async fn example() -> Result<(), Box<dyn Error>> {
     ///     let data = "\
     /// city,country,popcount
@@ -628,9 +619,10 @@ where
     /// # Example
     ///
     /// ```
+    /// # use tokio1 as tokio;
     /// use std::error::Error;
     /// use tokio::io;
-    /// use tokio::stream::StreamExt;
+    /// use tokio_stream::StreamExt;
     /// use csv_async::{AsyncReader, Position};
     ///
     /// # fn main() { tokio::runtime::Runtime::new().unwrap().block_on(async {example().await.unwrap()}); }
@@ -693,7 +685,7 @@ mod tests {
     use std::task::{Context, Poll};
 
     use tokio::io;
-    use tokio::stream::StreamExt;
+    use tokio_stream::StreamExt;
     use tokio::runtime::Runtime;
 
     use crate::byte_record::ByteRecord;
@@ -1146,12 +1138,12 @@ mod tests {
             fn poll_read(
                 self: Pin<&mut Self>,
                 _cx: &mut Context,
-                _buf: &mut [u8]
-            ) -> Poll<Result<usize, io::Error>> {
+                _buf: &mut tokio::io::ReadBuf
+            ) -> Poll<Result<(), io::Error>> {
                 Poll::Ready(Err(io::Error::new(io::ErrorKind::Other, "Broken reader")))
             }
         }
-        impl std::marker::Unpin for FailingRead {}
+        impl Unpin for FailingRead {}
     
         Runtime::new().unwrap().block_on(async {
             let mut record_results = AsyncReader::from_reader(FailingRead).into_records();
